@@ -1534,7 +1534,7 @@ def schedules_get(context, id_, team_name):
 @click.option('--intervalunit')
 @click.option('--history', is_flag=True)
 @click.pass_context
-def schedules_timeline(context, team_name, history, expand, interval=1, intervalunit="weeks"):  # pylint: disable=too-many-locals, too-many-arguments
+def schedules_timeline(context, team_name, history, expand, interval=1, intervalunit="months"):  # pylint: disable=too-many-locals, too-many-arguments
     """
     Function to list the schedules for all teams
 
@@ -1557,7 +1557,8 @@ def schedules_timeline(context, team_name, history, expand, interval=1, interval
     print(f'\n On-call schedules - {rotation.lower()}')
 
     for item in result['data'][f'{rotation}']['rotations'][0]['periods']:
-        if not history and datetime.now() >= datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S"):
+        if not history and datetime.now().date() > datetime.strptime((item['startDate'].replace('Z', '')).split(".")[0], "%Y-%m-%dT%H:%M:%S").date():
+            print(item['startDate'])
             continue
         else:
             time_zone = pytz.timezone("UTC")
